package com.codigoparallevar.minicards.types;

import android.graphics.Canvas;
import android.util.Log;

import java.util.LinkedList;
import java.util.List;

public class RoundOutputConnector implements OutputConnector, Drawable {
    private int _centerX;
    private int _centerY;
    private final int _radius;
    private final Part _part;
    private Wire _currentWire = null;
    private final List<Wire> _wires;

    public RoundOutputConnector(Part part, int centerX, int centerY, int radius) {
        _part = part;
        _centerX = centerX;
        _centerY = centerY;
        _radius  = radius;
        _wires = new LinkedList<>();
    }

    @Override
    public boolean containsPoint(int x, int y) {
        return ((Math.abs(x - _centerX) <= _radius)
                && (Math.abs(y - _centerY) <= _radius));
    }


    @Override
    public Moveable getMoveable() {
        if (_currentWire == null) {
            startWire();
        }

        return _currentWire;
    }

    private void startWire() {
        _currentWire = new Wire(this, _centerX, _centerY);
    }

    @Override
    public void drop(Wire wire) {
        if (wire == _currentWire){
            _currentWire = null;
            _wires.add(wire);
        }
        else {
            Log.w("RoundOutputConnector",
                    "Asked to drop non matching wire "
                            + "(expected " + _currentWire + ", got " + wire + ")");
        }
    }

    @Override
    public void drawWires(Canvas canvas, boolean devMode) {
        for (Wire wire : _wires) {
            wire.draw(canvas, devMode);
        }

        if (_currentWire != null) {
            _currentWire.draw(canvas, devMode);
        }
    }

    @Override
    public void updatePosition(int x, int y) {
        _centerX = x;
        _centerY = y;
    }

    @Override
    public void draw(Canvas canvas, boolean devMode) {

    }
}
